@@ -22,8 +22,8 @@ our @EXPORT = qw(
   compile_output_to_note
 );
 
-# ABSTRACT: Test-time utilities for checking C headers, libraries, or OS features
-our $VERSION = '0.07'; # VERSION
+# ABSTRACT: Test-time utilities for checking C headers, libraries, or OS features (DEPRECATED)
+our $VERSION = '0.08'; # VERSION
 
 
 do {
@@ -155,11 +155,11 @@ __END__
 
 =head1 NAME
 
-Test::CChecker - Test-time utilities for checking C headers, libraries, or OS features
+Test::CChecker - Test-time utilities for checking C headers, libraries, or OS features (DEPRECATED)
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -178,6 +178,11 @@ version 0.07
 
 =head1 DESCRIPTION
 
+B<DEPRECATED>: The intention of this module was always to test L<Alien> modules
+(both L<Alien::Base> based and non-L<Alien::Base> based modules).  It has a number
+of shortcomings that I believe to be better addressed by L<Test::Alien>,
+so please consider using that for new projects, or even migrating existing code.
+
 This module is a very thin convenience wrapper around L<ExtUtils::CChecker> to make
 it useful for use in a test context.  It is intended for use with Alien modules
 which need to verify that libraries work as intended with the Compiler and
@@ -220,8 +225,8 @@ be passed unmodified as a hash to L<ExtUtils::CChecker> C<try_compile_run>).
 If the test fails, then the complete output will be reported using
 L<Test::More> C<diag>.
 
-You can have it report the output on success with L<#compile_output_to_diag>
-or L<#compile_output_to_note>.
+You can have it report the output on success with L</compile_output_to_diag>
+or L</compile_output_to_note>.
 
 In addition to the pass/fail and diagnostic output, this function
 will return true or false on success and failure respectively.
@@ -290,6 +295,12 @@ Report output using L<Test::More> C<diag> on success (output is always reported
 
 Report output using L<Test::More> C<note> on success (output is always reported on failure using C<diag>).
 
+=head1 SEE ALSO
+
+Please consider using the official replacement:
+
+L<Test::Alien>
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
